# `v1` API

## BOED

::: src.inspeqtor.v1.boed

## Constant

::: src.inspeqtor.v1.constant

## Control

::: src.inspeqtor.v1.control

## Data

::: src.inspeqtor.v1.data

## Linen

::: src.inspeqtor.v1.models.linen

## NNX

::: src.inspeqtor.v1.models.nnx

## Optimize

::: src.inspeqtor.v1.optimize

## Physics

::: src.inspeqtor.v1.physics

## Predefined

::: src.inspeqtor.v1.predefined

## Probabilistic

::: src.inspeqtor.v1.probabilistic

## Utilities

::: src.inspeqtor.v1.utils

## Visualization

::: src.inspeqtor.v1.visualization
